@@ -69,20 +69,15 @@ class ConfigData:
                         self.fieldmap[tv] = {"device": self.roomcontrollers[k], "stateName": tk}
 
                 if v["type"] == 'InfoOnlyAnalog':
-                    control_format = ""
-                    if 'details' in v:
-                        if 'format' in v["details"]:
-                            control_format = v["details"]["format"]
-                            _LOGGER.debug("    format: {0}".format(control_format))
+                    _LOGGER.debug("  InfoOnlyAnalog - {0}".format(k))
+                    self.sensors[k] = LoxInfoOnlyAnalog(k, roomName + v["name"], v["type"], v)
 
-                    self.sensors[k] = LoxInfoOnlyAnalog(k, roomName + v["name"], v["type"])
-                    _LOGGER.debug("  Map states for InfoOnlyAnalog")
                     for tk,tv in v["states"].items():
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
                         self.fieldmap[tv] = {"device": self.sensors[k], "stateName": tk}
 
                 if v["type"] == 'InfoOnlyDigital':
-                    self.sensors[k] = LoxInfoOnlyDigital(k, roomName + v["name"], catName, v["details"], v["type"])
+                    self.sensors[k] = LoxInfoOnlyDigital(k, roomName + v["name"], catName, v["details"], v["type"], v)
                     _LOGGER.debug("  Map states for InfoOnlyDigital")
                     for tk,tv in v["states"].items():
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
